<?php
/**
 * Smarty Theme Functions
 *
 * @author Gogoneata Cristian <gogoneata_cristian@yahoo.com>
 * @package WordPress
 * @subpackage Smarty
 */

$theme_name = "Smarty";
$theme_version = "1.0";
global $theme_name, $theme_version, $dependency_css;
$dependency_css = array();

@define( 'PARENT_DIR', get_template_directory() );
@define( 'CHILD_DIR', get_stylesheet_directory() );

@define( 'PARENT_URL', get_template_directory_uri() );
@define( 'CHILD_URL', get_stylesheet_directory_uri() );

// Re-define meta box path and URL
define( 'RWMB_URL', trailingslashit( get_template_directory_uri() . '/admin/meta-box/' ) );
define( 'RWMB_DIR', trailingslashit( get_template_directory(). '/admin/meta-box/' ) );

// Load plugins
require_once PARENT_DIR . '/lib/class-tgm-plugin-activation.php';
include PARENT_DIR . '/lib/register-tgm-plugins.php';

// Include the meta box script
require_once RWMB_DIR . 'meta-box.php';
    // Include the meta box options
    include PARENT_DIR.'/lib/metaboxes-new.php';

include get_template_directory() . '/admin/customizer/options.php';

// Set VC as part of the theme
if(function_exists('vc_set_as_theme')) {
    vc_set_as_theme($disable_updater = true);
    vc_set_template_dir(PARENT_DIR.'/lib/visualcomposer/vc_templates/');
    require_once (PARENT_DIR . '/lib/load-vc-modules.php');
    $dependency_css[] = 'js_composer_front';
}

require_once (PARENT_DIR . '/lib/custom-post-types.php');

// Include widgets
require_once (PARENT_DIR . '/lib/widgets.php');
// Include love-this function
require_once (PARENT_DIR . '/lib/love-this.php');


// Verify if woocommerce is active
if ( ! function_exists( 'is_woocommerce_activated' ) ) {
    function is_woocommerce_activated() {
        if ( class_exists( 'woocommerce' ) ) { 
            return true;
            $dependency_css[] = 'woocommerce-general'; 
        } else { 
            return false;
        }
    }
}

// Verify if WPML is active
if ( ! function_exists( 'is_wpml_activated' ) ) {
    function is_wpml_activated() {
        if ( class_exists( 'SitePressLanguageSwitcher' ) ) { 
            return true; 
        } else { 
            return false;
        }
    }
}

/**
 * Load woocommerce functions
 */
if (is_woocommerce_activated()) {
    require_once PARENT_DIR . '/lib/theme-woocommerce.php';
} 

/**
 * Maximum allowed width of content within the theme.
 */
if (!isset($content_width)) {
    $content_width = 1170;
}

/**
 * Setup Theme Functions
 *
 */
if (!function_exists('smarty_theme_setup')):
    function smarty_theme_setup() {

        load_theme_textdomain('okthemes', get_template_directory() . '/lang');

        add_theme_support('automatic-feed-links');
        add_theme_support('post-thumbnails');
        add_theme_support('post-formats', array( 'aside', 'image', 'gallery', 'link', 'quote', 'status', 'video', 'audio', 'chat' ));
        add_theme_support('woocommerce');
        add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );
        
        $defaults = array(
            'default-color'          => 'F1F6F7',
            'default-image'          => '',
            'default-repeat'         => '',
            'default-position-x'     => '',
        );
        add_theme_support( 'custom-background', $defaults);

        register_nav_menus(
            array(
                'main-menu' => __('Main Menu', 'okthemes'),
                'footer-menu' => __('Footer Menu', 'okthemes'),
            ));
        // load custom walker menu class file
        require (PARENT_DIR . '/lib/nav/class-bootstrapwp_walker_nav_menu.php');

        add_image_size( 'testimonials', 70, 70, true); //70x70px
        add_image_size( 'widget-thumbs', 60, 60, true); //60x60px
    }
endif;
add_action('after_setup_theme', 'smarty_theme_setup');

/**
 * Define post thumbnail size.
 * Add two additional image sizes.
 *
 */
function smarty_images() {
    add_theme_support( 'post-thumbnails' );
    set_post_thumbnail_size('full');
    // This theme uses its own gallery styles.
    add_filter( 'use_default_gallery_style', '__return_false' );
}

/**
 * Load CSS styles for theme.
 *
 */
function smarty_styles_loader() {
    global $dependency_css;
    wp_enqueue_style('smarty-style', get_template_directory_uri() . '/assets/bootstrap/css/bootstrap.min.css', false, '1.0', 'all');
    wp_enqueue_style('smarty-font-elegant', get_template_directory_uri() . '/assets/elegant-font/style.css', false, '1.0', 'all');
    wp_enqueue_style('smarty-font-social', get_template_directory_uri() . '/assets/social-font/stylesheets.css', false, '1.0', 'all');
    wp_register_style('isotope', get_template_directory_uri() . '/styles/isotope.css', false, '1.0', 'all');
    wp_register_style('magnific', get_template_directory_uri() . '/styles/magnific-popup.css', false, '1.0', 'all');
    wp_enqueue_style('owlcarouselbase', get_template_directory_uri() . '/styles/owl.carousel.css', false, '1.0', 'all');
    wp_enqueue_style('owlcarouseltheme', get_template_directory_uri() . '/styles/owl.theme.css', false, '1.0', 'all');
    wp_enqueue_style('owlcarouseltransitions', get_template_directory_uri() . '/styles/owl.transitions.css', false, '1.0', 'all');

    wp_enqueue_style('smarty-default', get_stylesheet_uri(), $dependency_css);

}
add_action('wp_enqueue_scripts', 'smarty_styles_loader');

/**
 * Load JavaScript and jQuery files for theme.
 *
 */
function smarty_scripts_loader() {

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
    
    wp_enqueue_script('bootstrap-js', get_template_directory_uri() . '/assets/bootstrap/js/bootstrap.min.js', array('jquery'),'1.0',true);
    wp_enqueue_script('classie', get_template_directory_uri() . '/js/classie.js', array('jquery'),'1.0',true);
    wp_enqueue_script('uisearch', get_template_directory_uri() . '/js/uisearch.js', array('jquery'),'1.0',true);
    wp_enqueue_script('hoverintent', get_template_directory_uri() . '/js/hoverintent.js', array('jquery'), '1.0', true);
    wp_enqueue_script('menu', get_template_directory_uri() . '/js/menu.js', array('jquery'), '1.0', true);
    wp_register_script('isotope', get_template_directory_uri() . '/js/jquery.isotope.min.js', array('jquery'), '1.0', true);
    wp_register_script('magnific', get_template_directory_uri() . '/js/jquery.magnific-popup.min.js', array('jquery'), '1.0', true);
    wp_register_script('owlcarousel', get_template_directory_uri() . '/js/owl.carousel.min.js', array('jquery'), '1.0', true);
    wp_register_script('countto', get_template_directory_uri() . '/js/jquery.countto.js', array('jquery'), '1.0', true);

    wp_register_script('gmaps',get_template_directory_uri() ."/js/jquery.gmap.min.js",array('jquery'),'1.2.3',true);
    wp_register_script('google-map',"//maps.google.com/maps/api/js?sensor=false");
    wp_register_script('jvalidate',get_template_directory_uri() ."/js/jquery.validate.min.js",array('jquery'),'1.2.3',true);
    wp_register_script('videobackground',get_template_directory_uri() ."/js/jquery.videobackground.js",array('jquery'),'1.2.3',true);
    wp_enqueue_script('custom', get_template_directory_uri() . '/js/custom.js', array('jquery'), '1.0', true);
  
    wp_deregister_script('mediaelement');
    wp_enqueue_script('mediaelement',get_template_directory_uri() .'/js/mejsfixed.js', array( 'jquery' ), '' ,true);
}
add_action('wp_enqueue_scripts', 'smarty_scripts_loader');

//Admin enqueue script for metabox
function smarty_admin_metabox_script_loader() {
    //Enqueue only on page, post and post type
    $screen = get_current_screen();
    if( $screen->id === 'page' OR $screen->id === 'post' OR $screen->post_type === 'portfolio_cpt'  ){
        wp_enqueue_script( 'jquery-custom-admin', get_template_directory_uri() . '/js/jquery.custom.admin.js', array( 'jquery' ), '1.2.3', true );
    }
}
add_action( 'admin_enqueue_scripts', 'smarty_admin_metabox_script_loader' );


/**
 * Define theme's widget areas.
 *
 */
function smarty_widgets_init() {


    register_sidebar(
        array(
            'name'          => __('Page Sidebar', 'okthemes'),
            'id'            => 'sidebar-page',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => "</div>",
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>',
        )
    );

    register_sidebar(
        array(
            'name'          => __('Posts Sidebar', 'okthemes'),
            'id'            => 'sidebar-posts',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => "</div>",
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>',
        )
    );

    register_sidebar(
        array(
            'name'          => __('Search Sidebar', 'okthemes'),
            'id'            => 'sidebar-search',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => "</div>",
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>'
        )
    );

    register_sidebar(
        array(
            'name'          => __('Portfolio Sidebar', 'okthemes'),
            'id'            => 'sidebar-portfolio',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>'
        )
    );

    register_sidebar(
        array(
            'name'          => __('Shop Sidebar', 'okthemes'),
            'id'            => 'sidebar-shop',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>'
        )
    );

    register_sidebar(
        array(
            'name'          => __('Contact Sidebar', 'okthemes'),
            'id'            => 'sidebar-contact',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>'
        )
    );

    register_sidebar(
        array(
            'name'          => __('Footer First Sidebar', 'okthemes'),
            'id'            => 'sidebar-footer-first',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>'
        )
    );

    register_sidebar(
        array(
            'name'          => __('Footer Second Sidebar', 'okthemes'),
            'id'            => 'sidebar-footer-second',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>'
        )
    );

    register_sidebar(
        array(
            'name'          => __('Footer Third Sidebar', 'okthemes'),
            'id'            => 'sidebar-footer-third',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>'
        )
    );

    register_sidebar(
        array(
            'name'          => __('Footer Fourth Sidebar', 'okthemes'),
            'id'            => 'sidebar-footer-fourth',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>'
        )
    );

}
add_action('init', 'smarty_widgets_init');


/**
 * Display template for comments and pingbacks.
 *
 */
if (!function_exists('smarty_comment')) :
    function smarty_comment($comment, $args, $depth)
    {
        $GLOBALS['comment'] = $comment;
        switch ($comment->comment_type) :
            case 'pingback' :
            case 'trackback' : ?>

                <li <?php comment_class('media, comment'); ?> id="comment-<?php comment_ID(); ?>">
                    <div class="media-body">
                        <p>
                            <?php _e('Pingback:', 'okthemes'); ?> <?php comment_author_link(); ?>
                        </p>
                    </div><!--/.media-body -->
                <?php
                break;
            default :
                // Proceed with normal comments.
                global $post; ?>

                <li <?php comment_class('media'); ?> id="li-comment-<?php comment_ID(); ?>">
                        <a href="<?php echo $comment->comment_author_url;?>" class="pull-left avatar-holder">
                            <i class="icon_circle-slelected"></i>
                            <?php echo get_avatar($comment, 42); ?>
                        </a>
                        <div class="media-body">
                            <h4 class="media-heading comment-author vcard">
                                <?php
                                printf('<cite class="fn">%1$s %2$s</cite>',
                                    get_comment_author_link(),
                                    // If current post author is also comment author, make it known visually.
                                    ($comment->user_id === $post->post_author) ? '<span class="label"> ' . __(
                                        'Post author',
                                        'okthemes'
                                    ) . '</span> ' : ''); ?>
                            </h4>
                            <p class="meta">
                                <?php printf('<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
                                        esc_url(get_comment_link($comment->comment_ID)),
                                        get_comment_time('c'),
                                        sprintf(
                                            __('%1$s at %2$s', 'okthemes'),
                                            get_comment_date(),
                                            get_comment_time()
                                        )
                                    ); ?>
                            </p>
                            <p class="reply">
                                <?php comment_reply_link( array_merge($args, array(
                                            'reply_text' => __('<i class="arrow_back"></i> Reply', 'okthemes'),
                                            'depth'      => $depth,
                                            'max_depth'  => $args['max_depth']
                                        )
                                    )); ?>
                            </p>

                            <?php if ('0' == $comment->comment_approved) : ?>
                                <p class="comment-awaiting-moderation"><?php _e(
                                    'Your comment is awaiting moderation.',
                                    'okthemes'
                                ); ?></p>
                            <?php endif; ?>

                            <?php comment_text(); ?>
                            
                            
                        </div>
                        <!--/.media-body -->
                <?php
                break;
        endswitch;
    }
endif;

/**
 * Post view functions
 *
 */

function getPostViews($postID){
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
        return __('No views', 'okthemes');
    }
    return sprintf( __('%s Views','okthemes') , $count );
}
function setPostViews($postID) {
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}


/**
 * Display template for post meta information.
 *
 */
if (!function_exists('smarty_posted_on')) :
    function smarty_posted_on() {
    // Translators: used between list items, there is a space after the comma.
    $categories_list = get_the_category_list( __( ', ', 'okthemes' ) );

    $date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a>',
        esc_url( get_permalink() ),
        esc_attr( get_the_time() ),
        esc_attr( get_the_date( 'c' ) ),
        esc_html( get_the_date() )
    );

    // Translators: 1 is category, 2 is the date, 3 is the author's name
    if ( $categories_list ) {
        $utility_text = __( '<span class="post-date"><i class="icon_clock_alt"></i> %2$s</span> <span class="post-category"><i class="icon_menu-square_alt2"></i> %1$s</span>', 'okthemes' );
    } else {
        $utility_text = __( '<span class="post-date"><i class="icon_clock_alt"></i> %2$s</span>', 'okthemes' );
    }

    printf(
        $utility_text,
        $categories_list,
        $date
    );

    //Show comments
    $num_comments = get_comments_number(); // get_comments_number returns only a numeric value

    if ( comments_open() ) {
        if ( $num_comments == 0 ) {
            $comments = __('No Comments','okthemes');
        } elseif ( $num_comments > 1 ) {
            $comments = $num_comments . __(' Comments','okthemes');
        } else {
            $comments = __('1 Comment','okthemes');
        }
        $write_comments = '<a href="' . get_comments_link() .'">'. $comments.'</a>';
    } else {
        $write_comments =  __('Comments off','okthemes');
    }
    echo '<span class="post-comments"><i class="icon_comment_alt"></i> '.$write_comments.'</span>';
    
    //Show post views
    echo '<span class="post-views"><i class="icon_compass_alt"></i> '.getPostViews(get_the_ID()).'</span>';

    //Show love it button
    if( function_exists('gg_love_this') ) gg_love_this("pull-right");

}

endif;


if ( ! function_exists( 'smarty_post_nav' ) ) :
/**
 * Displays navigation to next/previous post when applicable.
*/
function smarty_post_nav() {
    global $post;

    // Don't print empty markup if there's nowhere to navigate.
    $previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
    $next     = get_adjacent_post( false, '', false );

    if ( is_single() && !is_attachment() ) {
        if ( get_post_type() == 'portfolio_cpt' ) {
            $nav_base_link = get_theme_mod('portfolio_nav_base_link');
        } else {
            $nav_base_link = get_theme_mod('blog_nav_base_link');
        }
    }

    if ( ! $next && ! $previous )
        return;
    if (( ! get_theme_mod('portfolio_inner_nav', true) == 1) && ( get_post_type() == 'portfolio_cpt' ))
        return;
    if (( ! get_theme_mod('blog_inner_nav', true) == 1) && ( get_post_type() == 'post' ))
        return;
    ?>
    <nav class="navigation post-navigation hidden-xs" role="navigation">
        <div class="nav-links">
            <ul class="pagination">
                <li <?php if(!get_adjacent_post(false, '', true)) { echo 'class="disabled"'; } ?>>
                    <?php previous_post_link( '%link', _x( '<span class="meta-nav"><i class="arrow_carrot-2left"></i></span>', 'Previous post link', 'okthemes' ) ); ?>
                    <?php if(!get_adjacent_post(false, '', true)) { echo '<span class="meta-nav"><i class="arrow_carrot-2left"></i></span>'; } // if there are no older articles ?>
                </li>
                <li class="post-base"><a href="<?php echo $nav_base_link; ?>"><i class="icon_grid-3x3"></i></a></li>
                <li <?php if(!get_adjacent_post(false, '', false)) { echo 'class="disabled"'; } ?>>
                    <?php next_post_link( '%link', _x( '<span class="meta-nav"><i class="arrow_carrot-2right"></i></span>', 'Next post link', 'okthemes' ) ); ?>
                    <?php if(!get_adjacent_post(false, '', false)) { echo '<span class="meta-nav"><i class="arrow_carrot-2right"></i></span>'; } // if there are no newer articles ?>
                </li>
            </ul>
        </div><!-- .nav-links -->
    </nav><!-- .navigation -->
    <?php
}
endif;

if ( ! function_exists( 'smarty_page_footer_message_box' ) ) :
/**
 * Display page footer message box
*/
function smarty_page_footer_message_box() {
    global $post;

    if (is_page() || is_single()) {
        $post_id = $post->ID;
    } elseif (is_woocommerce_activated()) {
        if (is_woocommerce() || is_product_category()) {
            $shop_page_id = woocommerce_get_page_id( 'shop' );
            $post_id = $shop_page_id;
        }
    }

    ?>
    
    <?php
    $page_footer_box = rwmb_meta('gg_page_footer_box','',$post_id);
    $page_footer_heading = rwmb_meta('gg_page_footer_heading','',$post_id);
    $page_footer_desc = rwmb_meta('gg_page_footer_desc','',$post_id);
    $page_footer_first_button_name = rwmb_meta('gg_page_footer_first_button_name','',$post_id);
    $page_footer_first_button_link = rwmb_meta('gg_page_footer_first_button_link','',$post_id);
    $page_footer_second_button_name = rwmb_meta('gg_page_footer_second_button_name','',$post_id);
    $page_footer_second_button_link = rwmb_meta('gg_page_footer_second_button_link','',$post_id);
    ?>
    <?php if ($page_footer_box) { ?>
    <section class="page-footer-message">
    <div class="container">
        <div class="row">
            <div class="col-xs-12 col-md-8">
                <h1><?php echo $page_footer_heading; ?></h1>
                <p><?php echo $page_footer_desc; ?></p>
            </div>
            <div class="col-xs-12 col-md-4">
                <div class="btn-group btn-group-justified">
                    <a class="btn theme_color_emerald" href="<?php echo $page_footer_first_button_link; ?>"><?php echo $page_footer_first_button_name; ?></a>
                    <a class="btn theme_color_concrete" href="<?php echo $page_footer_second_button_link; ?>"><?php echo $page_footer_second_button_name; ?></a>
                </div>    
            </div>            
        </div>
    </div>
    </section>
    <?php } ?>

    <?php
}
endif;

if ( ! function_exists( 'smarty_page_header' ) ) :
/**
 * Display page header
*/
function smarty_page_header() {
    global $post;

    if (is_home()) {
        $post_id = get_option('page_for_posts');
    } elseif (is_page()) {
        $post_id = $post->ID;
    } elseif (is_woocommerce_activated()) {
        if (is_woocommerce() || is_product_category()) {
            $shop_page_id = woocommerce_get_page_id( 'shop' );
            $post_id = $shop_page_id;
        }
    } else {
        $post_id = $post->ID;
    }

    ?>
    
    <?php
    $page_header = rwmb_meta('gg_page_header','',$post_id); 
    $page_heading_position = rwmb_meta('gg_page_heading_pos_select','',$post_id);
    $page_title_short_desc = rwmb_meta('gg_page_title_short_desc','',$post_id);
    $page_header_image_overlay = rwmb_meta('gg_page_header_image_overlay','',$post_id);
    ?>

    <?php if (!is_front_page() && !(is_woocommerce_activated() && is_product()) ) { ?>
        
        <?php if ($page_header == 1 || $page_header == '' ) { ?>

        <section id="subheader" class="<?php if ( has_post_thumbnail($post_id) ) { echo 'has_header_image'; } ?>">
            
            <?php if ( has_post_thumbnail()) { ?>
            <div class="page-header-image">
                <?php if ( $page_header_image_overlay == '1' ) echo '<div class="gg-image-overlay"></div>'; ?>
                    <?php  
                        if (is_woocommerce_activated() && ( is_shop() || is_product_category() ) ) {    
                           $large_image_url = wp_get_attachment_image_src( get_post_thumbnail_id($post_id), 'full');
                           echo '<a href="' . $large_image_url[0] . '" title="' . the_title_attribute('echo=0') . '" >';
                           echo get_the_post_thumbnail($post_id, 'full'); 
                           echo '</a>';
                        //check for blog page   
                        } elseif (is_home()) {
                            echo get_the_post_thumbnail($post_id, 'full');
                        } else {
                            echo get_the_post_thumbnail($post_id, 'full');     
                        } 
                    ?>
            </div>
            <?php } ?>

            <div class="container <?php echo $page_heading_position; ?>">
                <div class="row">
                    <div class="col-xs-12 col-md-12">
                        <?php if (function_exists('smarty_breadcrumbs')) {
                            smarty_breadcrumbs();
                        } ?>
                        
                        <?php if ( !is_tax('product_tag') ) { ?>
                        <header class="page-title">
                            <?php if (is_woocommerce_activated() && (is_shop() || is_product_category())) { ?>
                                
                                <h1><?php woocommerce_page_title(); ?></h1>
                            
                            <?php } elseif (is_home()) { ?>

                            <h1><?php echo get_the_title($post_id);?></h1>

                            <?php } else { ?>

                                <h1><?php the_title();?></h1>
                            
                            <?php } ?>

                            <p><?php echo $page_title_short_desc ?></p>
                        </header>
                        <?php } ?>
                        
                    </div><!--/.col-12 col-sm-12 col-lg-12 -->
                </div><!--/.row -->
            </div>
        </section>
        <?php } ?>
    <?php } ?>

    <?php
}
endif;

if ( ! function_exists( 'smarty_page_header_slider' ) ) :
/**
 * Display page header
*/
function smarty_page_header_slider() {
    global $post;
    

    if (is_home()) {
        $post_id = get_option('page_for_posts');
    } elseif (is_page()) {
        $post_id = $post->ID;
    } elseif (is_woocommerce_activated()) {
        if (is_woocommerce() || is_product_category()) {
            $shop_page_id = woocommerce_get_page_id( 'shop' );
            $post_id = $shop_page_id;
        }
    } else {
        $post_id = $post->ID;
    }

    ?>
    
    <?php
    $page_header_slider = rwmb_meta('gg_page_header_slider','',$post_id);
    $rev_slider_alias = rwmb_meta('gg_page_header_slider_select','',$post_id);
    ?>
    <?php if ($page_header_slider) { ?>
    <section id="subheader-slider">
        <?php echo do_shortcode('[rev_slider '.$rev_slider_alias.']'); ?>
    </section>
    <?php } ?>

    <?php
}
endif;

/**
 * Tags widget style
 *
 */

function custom_tag_cloud_widget($args) {
    $args['number'] = 0; //adding a 0 will display all tags
    $args['largest'] = 14; //largest tag
    $args['smallest'] = 14; //smallest tag
    $args['unit'] = 'px'; //tag font unit
    $args['format'] = 'list'; //ul with a class of wp-tag-cloud
    return $args;
}
add_filter( 'widget_tag_cloud_args', 'custom_tag_cloud_widget' );



/**
 * Display template for post footer information (in single.php).
 *
 */
if (!function_exists('smarty_posted_in')) :
    function smarty_posted_in() {

    // Translators: used between list items, there is a space after the comma.
    $tag_list = get_the_tag_list('<ul class="inline post-tags"><li class="btn btn-default">','</li><li class="btn btn-default">','</li></ul>');

    // Translators: 1 is the tags
    if ( $tag_list ) {
        $utility_text = __( '%1$s', 'okthemes' );
    } 

    printf($tag_list);

}

endif;

function smarty_user_agent() {
    global $smarty_is_iphone, $smarty_is_ipad, $smarty_is_android, $is_nav_mobile;
    $smarty_is_iphone  = stripos($_SERVER['HTTP_USER_AGENT'],"iPhone");
    $smarty_is_ipad    = stripos($_SERVER['HTTP_USER_AGENT'],"iPad");
    $smarty_is_android = stripos($_SERVER['HTTP_USER_AGENT'],"Android");

    if ($smarty_is_iphone || $smarty_is_android || $smarty_is_ipad) {
        $is_nav_mobile = 'is-hidden';
    }
}

add_action( 'init', 'smarty_user_agent');


/**
 * Adds custom classes to the array of body classes.
 *
 */
function smarty_body_classes($classes)
{
    if (!is_multi_author()) {
        $classes[] = 'single-author';
    }

    // add classes for mobile agents
    global $smarty_is_iphone, $smarty_is_android, $smarty_is_ipad;
    
    if($smarty_is_iphone){
        $classes[] = 'smarty-agent-iphone';
    }
    else if($smarty_is_ipad){
        $classes[] = 'smarty-agent-ipad';
    }
    else if($smarty_is_android){
        $classes[] = 'smarty-agent-android';
    }

    // current language code if wpml is installed
    if( function_exists( 'icl_get_home_url' ) ) {
          $classes[] = ICL_LANGUAGE_CODE;
    }

    return $classes;
}
add_filter('body_class', 'smarty_body_classes');

/**
 * Get first image in a post
 *
 */

function smarty_get_first_image() {
  global $post, $posts;
  $first_img = '';
  ob_start();
  ob_end_clean();
  $output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
  $first_img = $matches [1] [0];

  return $first_img;
}

/**
 * Define default page titles.
 *
 */
function smarty_wp_title($title, $sep)
{
    global $paged, $page;
    if (is_feed()) {
        return $title;
    }
    // Add the site name.
    $title .= get_bloginfo('name');
    // Add the site description for the home/front page.
    $site_description = get_bloginfo('description', 'display');
    if ($site_description && (is_home() || is_front_page())) {
        $title = "$title $sep $site_description";
    }
    // Add a page number if necessary.
    if ($paged >= 2 || $page >= 2) {
        $title = "$title $sep " . sprintf(__('Page %s', 'okthemes'), max($paged, $page));
    }
    return $title;
}
add_filter('wp_title', 'smarty_wp_title', 10, 2);

/**
 * Display template for breadcrumbs.
 *
 */
function smarty_breadcrumbs() {
 
  /* === OPTIONS === */
  $text['home']     = '<i class="icon_house"></i>'; // text for the 'Home' link
  $text['category'] = 'Archive by Category "%s"'; // text for a category page
  $text['search']   = 'Search Results for "%s" Query'; // text for a search results page
  $text['tag']      = 'Posts Tagged "%s"'; // text for a tag page
  $text['author']   = 'Articles Posted by %s'; // text for an author page
  $text['404']      = 'Error 404'; // text for the 404 page
 
  $showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show
  $showOnHome  = 0; // 1 - show breadcrumbs on the homepage, 0 - don't show
  $delimiter   = ''; // delimiter between crumbs
  $before      = '<li class="active">'; // tag before the current crumb
  $after       = '</li>'; // tag after the current crumb
  /* === END OF OPTIONS === */
 
  global $post;
  $homeLink = home_url() . '/';
  $linkBefore = '<li typeof="v:Breadcrumb">';
  $linkAfter = '</li>';
  $linkAttr = ' rel="v:url" property="v:title"';
  $link = $linkBefore . '<a' . $linkAttr . ' href="%1$s">%2$s</a>' . $linkAfter;
 
  if (is_home() || is_front_page()) {
 
    if ($showOnHome == 1) echo '<ul class="breadcrumb"><a href="' . $homeLink . '">' . $text['home'] . '</a></ul>';
 
  } else {
 
    echo '<ul class="breadcrumb" >' . sprintf($link, $homeLink, $text['home']) . $delimiter;
 
    if ( is_category() ) {
      $thisCat = get_category(get_query_var('cat'), false);
      if ($thisCat->parent != 0) {
        $cats = get_category_parents($thisCat->parent, TRUE, $delimiter);
        $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
        $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
        echo $cats;
      }
      echo $before . sprintf($text['category'], single_cat_title('', false)) . $after;
    
    //Begin code for woocommerce
    } elseif ( is_tax('product_cat') ) {


        $current_term = get_term_by( 'slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) );

        $ancestors = array_reverse( get_ancestors( $current_term->term_id, get_query_var( 'taxonomy' ) ) );

        foreach ( $ancestors as $ancestor ) {
            $ancestor = get_term( $ancestor, get_query_var( 'taxonomy' ) );

            echo $before .  '<a href="' . get_term_link( $ancestor->slug, get_query_var( 'taxonomy' ) ) . '">' . esc_html( $ancestor->name ) . '</a>' . $after . $delimiter;
        }

        echo $before . esc_html( $current_term->name ) . $after;

    } elseif ( is_tax('portfolio_category') ) {


        $current_term = get_term_by( 'slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) );

        $ancestors = array_reverse( get_ancestors( $current_term->term_id, get_query_var( 'taxonomy' ) ) );

        foreach ( $ancestors as $ancestor ) {
            $ancestor = get_term( $ancestor, get_query_var( 'taxonomy' ) );

            echo $before .  '<a href="' . get_term_link( $ancestor->slug, get_query_var( 'taxonomy' ) ) . '">' . esc_html( $ancestor->name ) . '</a>' . $after . $delimiter;
        }

        echo $before . esc_html( $current_term->name ) . $after;    

    } elseif ( is_tax('product_tag') ) {

        echo $before . __( 'Products tagged &ldquo;', 'okthemes' ) . single_tag_title('', false) . '&rdquo;' . $after;
    
    } elseif ( is_post_type_archive('product') ) {

        $_name = woocommerce_get_page_id( 'shop' ) ? get_the_title( woocommerce_get_page_id( 'shop' ) ) : '';

        if ( ! $_name ) {
            $product_post_type = get_post_type_object( 'product' );
            $_name = $product_post_type->labels->singular_name;
        }

        if ( is_search() ) {

            echo $before . '<a href="' . get_post_type_archive_link('product') . '">' . $_name . '</a>' . $delimiter . __( 'Search results for &ldquo;', 'okthemes' ) . get_search_query() . '&rdquo;' . $after;

        } elseif ( is_paged() ) {

            echo $before . '<a href="' . get_post_type_archive_link('product') . '">' . $_name . '</a>' . $after;

        } else {

            echo $before . $_name . $after;

        }
    
    //End code for woocommerce
    
    } elseif ( is_search() ) {
      echo $before . sprintf($text['search'], get_search_query()) . $after;
 
    } elseif ( is_day() ) {
      echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
      echo sprintf($link, get_month_link(get_the_time('Y'),get_the_time('m')), get_the_time('F')) . $delimiter;
      echo $before . get_the_time('d') . $after;
 
    } elseif ( is_month() ) {
      echo sprintf($link, get_year_link(get_the_time('Y')), get_the_time('Y')) . $delimiter;
      echo $before . get_the_time('F') . $after;
 
    } elseif ( is_year() ) {
      echo $before . get_the_time('Y') . $after;
 
    } elseif ( is_single() && !is_attachment() ) {
          if ( get_post_type() == 'product' ) {
    
                if ( $terms = wp_get_post_terms( $post->ID, 'product_cat', array( 'orderby' => 'parent', 'order' => 'DESC' ) ) ) {
    
                    $main_term = $terms[0];
    
                    $ancestors = array_reverse( get_ancestors( $main_term->term_id, 'product_cat' ) );
    
                    $ancestors = array_reverse( $ancestors );
    
                    foreach ( $ancestors as $ancestor ) {
                        $ancestor = get_term( $ancestor, 'product_cat' );
    
                        echo $before . '<a href="' . get_term_link( $ancestor->slug, 'product_cat' ) . '">' . $ancestor->name . '</a>' . $after . $delimiter;
                    }
    
                    echo $before . '<a href="' . get_term_link( $main_term->slug, 'product_cat' ) . '">' . $main_term->name . '</a>' . $after . $delimiter;
    
                }
    
                echo $before . get_the_title() . $after;

        } elseif ( get_post_type() == 'portfolio_cpt' ) {

            if ( $terms = wp_get_post_terms( $post->ID, 'portfolio_category', array( 'orderby' => 'parent', 'order' => 'DESC' ) ) ) {

                $post_type = get_post_type_object(get_post_type());
    
                $main_term = $terms[0];

                $ancestors = array_reverse( get_ancestors( $main_term->term_id, 'portfolio_category' ) );

                $ancestors = array_reverse( $ancestors );

                foreach ( $ancestors as $ancestor ) {
                    $ancestor = get_term( $ancestor, 'portfolio_category' );

                    echo $before . '<a href="' . get_term_link( $ancestor->slug, 'portfolio_category' ) . '">' . $ancestor->name . '</a>' . $after . $delimiter;
                }

                echo $before . '<a href="' . get_term_link( $main_term->slug, 'portfolio_category' ) . '">' . $main_term->name . '</a>' . $after . $delimiter;

            }
            echo $before . get_the_title() . $after;

        } elseif ( get_post_type() != 'post' ) {
          
        $post_type = get_post_type_object(get_post_type());
        $slug = $post_type->rewrite;
        printf($link, $homeLink . '/' . $slug['slug'] . '/', $post_type->labels->singular_name);
        if ($showCurrent == 1) echo $delimiter . $before . get_the_title() . $after;
        
        } else {
        $cat = get_the_category(); $cat = $cat[0];
        $cats = get_category_parents($cat, TRUE, $delimiter);
        if ($showCurrent == 0) $cats = preg_replace("#^(.+)$delimiter$#", "$1", $cats);
        $cats = str_replace('<a', $linkBefore . '<a' . $linkAttr, $cats);
        $cats = str_replace('</a>', '</a>' . $linkAfter, $cats);
        echo $cats;
        if ($showCurrent == 1) echo $before . get_the_title() . $after;
      }
 
    } elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {
      $post_type = get_post_type_object(get_post_type());
      echo $before . $post_type->labels->singular_name . $after;
 
    } elseif ( is_page() && !$post->post_parent ) {
      if ($showCurrent == 1) echo $before . get_the_title() . $after;
 
    } elseif ( is_page() && $post->post_parent ) {
      $parent_id  = $post->post_parent;
      $breadcrumbs = array();
      while ($parent_id) {
        $page = get_page($parent_id);
        $breadcrumbs[] = sprintf($link, get_permalink($page->ID), get_the_title($page->ID));
        $parent_id  = $page->post_parent;
      }
      $breadcrumbs = array_reverse($breadcrumbs);
      for ($i = 0; $i < count($breadcrumbs); $i++) {
        echo $breadcrumbs[$i];
        if ($i != count($breadcrumbs)-1) echo $delimiter;
      }
      if ($showCurrent == 1) echo $delimiter . $before . get_the_title() . $after;
 
    } elseif ( is_tag() ) {
      echo $before . sprintf($text['tag'], single_tag_title('', false)) . $after;
 
    } elseif ( is_author() ) {
       global $author;
      $userdata = get_userdata($author);
      echo $before . sprintf($text['author'], $userdata->display_name) . $after;
 
    } elseif ( is_404() ) {
      echo $before . $text['404'] . $after;
    }
 
    if ( get_query_var('paged') ) {
      echo '<li>';
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' (';
      echo __('Page', 'okthemes') . ' ' . get_query_var('paged');
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ')';
      echo '</li>';  
    }
 
    echo '</ul>';
 
  }
} 
/**
 * Display template for pagination.
 *
 */
function pagination($pages = '', $range = 2)
{ 
     $showitems = ($range * 2)+1; 

     global $paged;
     if(empty($paged)) $paged = 1;

     if($pages == '')
     {
         global $wp_query;
         $pages = $wp_query->max_num_pages;
         if(!$pages)
         {
             $pages = 1;
         }
     }  

     if(1 != $pages)
     {
         echo "<ul class=\"pagination\">";
         echo "<li class=\"disabled\"><span class=\"img-rounded page-of\">Page ".$paged." of ".$pages."</span></li>";

         if($paged > 2 && $paged > $range+1 && $showitems < $pages) {
            echo "<li><a class=\"img-rounded\" href='".get_pagenum_link(1)."'>&laquo; First</a></li>";
         }
         if($paged > 1 && $showitems < $pages) {
            echo "<li><a class=\"img-rounded\" href='".get_pagenum_link($paged - 1)."'>&lsaquo; Previous</a></li>";
         }

         for ($i=1; $i <= $pages; $i++)
         {
             if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
             {
                 echo ($paged == $i)? "<li><span class=\"current img-rounded\">".$i."</span></li>":"<li><a class=\"img-rounded\" href='".get_pagenum_link($i)."' class=\"inactive\">".$i."</a></li>";
             }
         }

         if ($paged < $pages && $showitems < $pages) {
            echo "<li><a class=\"img-rounded\" href=\"".get_pagenum_link($paged + 1)."\">Next &rsaquo;</a></li>"; 
         }
            
         if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) {
            echo "<li><a class=\"img-rounded\" href='".get_pagenum_link($pages)."'>Last &raquo;</a></li>";
         }
            
         echo "</ul>\n";
     }
}

add_filter( 'the_password_form', 'custom_password_form' );
function custom_password_form() {
 
    global $post;
 
    $label = 'pwbox-'.(empty($post->ID) ? rand() : $post->ID);
 
    $output = '<form action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">
 
    <p>' . __("This post is password protected. To view it please enter your password below:","okthemes") . '</p>
 
    <div class="input-group"><span class="input-group-addon"><i class="icon_lock_alt"></i></span><label class="sr-only" for="' . $label . '">' . __("Password:", "okthemes") . '</label><input name="post_password" id="' . $label . '" type="password" placeholder=' . __("Password:","okthemes") . ' size="20" /><span class="input-group-btn"><input type="submit" name="Submit" value="' . esc_attr__("Submit","okthemes") . '" /></span></div></form>'; 
    return $output;
 
}

/**
 * Get tax term slug
 */
function gg_tax_terms_slug($taxonomy) {
    global $post, $post_id;
    // get post by post id
    $post = get_post($post->ID);
    // get post type by post
    $post_type = $post->post_type;
    // get post type taxonomies
    $terms = get_the_terms( $post->ID, $taxonomy );
    if ( !empty( $terms ) ) {
        $out = array();
        foreach ( $terms as $term )
            $out[] = $term->slug;
        $return = join( ' ', $out );
    }
    return $return;
}

// get taxonomies terms links
function portfolio_taxonomies_terms_links(){
  global $post;
  // get post by post id
  $post = get_post( $post->ID );

  // get post type by post
  $post_type = 'portfolio_cpt';

  // get post type taxonomies
  $taxonomy_slug = 'portfolio_category';

  $out = array();
    // get the terms related to post
    $terms = get_the_terms( $post->ID, $taxonomy_slug );

    if ( !empty( $terms ) ) {
      $out[] = "<ul class='list-inline list-unstyled'><li><i class='icon_menu-square_alt2'></i></li>";
      foreach ( $terms as $term ) {
        $out[] =
          '  <li><a href="'
        .    get_term_link( $term->slug, $taxonomy_slug ) .'">'
        .    $term->name
        . "</a></li>\n";
      }
      $out[] = "</ul>\n";
    }

  return implode('', $out );
}

add_filter('wpb_widget_title', 'override_widget_title', 10, 2);
function override_widget_title($output = '', $params = array('')) {
  $extraclass = (isset($params['extraclass'])) ? " ".$params['extraclass'] : "";
  return '<h3 class="entry-title'.$extraclass.'">'.$params['title'].'</h3>';
}

function add_wpb_to_body_if_shortcode($classes) {
    global $post;
    if (isset($post->post_content) && false !== stripos($post->post_content, '[vc_row')) {
        array_push($classes, 'wpb-is-on');
    } else {
        array_push($classes, 'wpb-is-off');
    }
    return $classes;
}

add_filter('body_class', 'add_wpb_to_body_if_shortcode', 100, 1);

/**
 * Replaces the login header logo
 */
add_action( 'login_head', 'wp_admin_login_style' );
function wp_admin_login_style() {
    if (get_theme_mod( 'admin_retina_logo', get_template_directory_uri() . '/images/logo-smarty-retina@2x.png' )) {
        echo '<style>
        .login h1 a { 
            background-image: url( '.get_theme_mod('admin_retina_logo', get_template_directory_uri() . '/images/logo-smarty-retina@2x.png').' ) !important; 
            background-size:'.get_theme_mod('admin_logo_width', '150').'px '.get_theme_mod('admin_logo_height','35').'px;
            width:'.get_theme_mod('admin_logo_width', '150').'px;
            height:'.get_theme_mod('admin_logo_height','35').'px;
            margin-bottom:15px; 
        }
        </style>';
    } elseif ( get_theme_mod( 'admin_logo', get_template_directory_uri() . '/images/logo-smarty.png' ) ) {
        echo '<style>
        .login h1 a { 
            background-image: url( '.get_theme_mod('admin_logo', get_template_directory_uri() . '/images/logo-smarty.png').' ) !important; 
            background-size:'.get_theme_mod('admin_logo_width', '150').'px '.get_theme_mod('admin_logo_height','35').'px;
            width:'.get_theme_mod('admin_logo_width', '150').'px;
            height:'.get_theme_mod('admin_logo_height','35').'px;
            margin-bottom:15px; 
        }
        </style>'; 
    }
}

/**
     * Color shift a hex value by a specific percentage factor
     *
     * @param string $supplied_hex Any valid hex value. Short forms e.g. #333 accepted.
     * @param string $shift_method How to shift the value e.g( +,up,lighter,>)
     * @param integer $percentage Percentage in range of [0-100] to shift provided hex value by
     * @return string shifted hex value
     * @version 1.0 2008-03-28
     */

if (!function_exists('su_hex_shift')) :
function su_hex_shift( $supplied_hex, $shift_method, $percentage = 50 ) {
    $shifted_hex_value = null;
    $valid_shift_option = FALSE;
    $current_set = 1;
    $RGB_values = array( );
    $valid_shift_up_args = array( 'up', '+', 'lighter', '>' );
    $valid_shift_down_args = array( 'down', '-', 'darker', '<' );
    $shift_method = strtolower( trim( $shift_method ) );

    // Check Factor
    if ( !is_numeric( $percentage ) || ($percentage = ( int ) $percentage) < 0 || $percentage > 100 ) {
        trigger_error( "Invalid factor", E_USER_ERROR );
    }

    // Check shift method
    foreach ( array( $valid_shift_down_args, $valid_shift_up_args ) as $options ) {
        foreach ( $options as $method ) {
            if ( $method == $shift_method ) {
                $valid_shift_option = !$valid_shift_option;
                $shift_method = ( $current_set === 1 ) ? '+' : '-';
                break 2;
            }
        }
        ++$current_set;
    }

    if ( !$valid_shift_option ) {
        trigger_error( "Invalid shift method", E_USER_ERROR );
    }

    // Check Hex string
    switch ( strlen( $supplied_hex = ( str_replace( '#', '', trim( $supplied_hex ) ) ) ) ) {
        case 3:
            if ( preg_match( '/^([0-9a-f])([0-9a-f])([0-9a-f])/i', $supplied_hex ) ) {
                $supplied_hex = preg_replace( '/^([0-9a-f])([0-9a-f])([0-9a-f])/i', '\\1\\1\\2\\2\\3\\3', $supplied_hex );
            } else {
                trigger_error( "Invalid hex color value", E_USER_ERROR );
            }
            break;
        case 6:
            if ( !preg_match( '/^[0-9a-f]{2}[0-9a-f]{2}[0-9a-f]{2}$/i', $supplied_hex ) ) {
                trigger_error( "Invalid hex color value", E_USER_ERROR );
            }
            break;
        default:
            trigger_error( "Invalid hex color length", E_USER_ERROR );
    }

    // Start shifting
    $RGB_values['R'] = hexdec( $supplied_hex{0} . $supplied_hex{1} );
    $RGB_values['G'] = hexdec( $supplied_hex{2} . $supplied_hex{3} );
    $RGB_values['B'] = hexdec( $supplied_hex{4} . $supplied_hex{5} );

    foreach ( $RGB_values as $c => $v ) {
        switch ( $shift_method ) {
            case '-':
                $amount = round( ((255 - $v) / 100) * $percentage ) + $v;
                break;
            case '+':
                $amount = $v - round( ($v / 100) * $percentage );
                break;
            default:
                trigger_error( "Oops. Unexpected shift method", E_USER_ERROR );
        }

        $shifted_hex_value .= $current_value = (
            strlen( $decimal_to_hex = dechex( $amount ) ) < 2
            ) ? '0' . $decimal_to_hex : $decimal_to_hex;
    }

    return '#' . $shifted_hex_value;
}
endif;

if (is_wpml_activated()) {
    function language_selector_flags(){
        $languages = icl_get_languages('skip_missing=0&orderby=code');
        if(!empty($languages)){
            foreach($languages as $l){
                if(!$l['active']) echo '<a href="'.$l['url'].'">';
                echo '<img src="'.$l['country_flag_url'].'" height="12" alt="'.$l['language_code'].'" width="18" />';
                if(!$l['active']) echo '</a>';
            }
        }
    }
}   