<?php
/**
 * Define image sizes
 */
function smarty_woocommerce_image_dimensions() {
	global $pagenow;
 
	if ( ! isset( $_GET['activated'] ) || $pagenow != 'themes.php' ) {
		return;
	}
  	$catalog = array(
		'width' 	=> '555',	// px
		'height'	=> '555',	// px
		'crop'		=> 1 		// true
	);
 
	$single = array(
		'width' 	=> '888',	// px
		'height'	=> '888',	// px
		'crop'		=> 1 		// true
	);
 
	$thumbnail = array(
		'width' 	=> '168',	// px
		'height'	=> '168',	// px
		'crop'		=> 1		// false
	);
	// Image sizes
	update_option( 'shop_catalog_image_size', $catalog ); 		// Product category thumbs
	update_option( 'shop_single_image_size', $single ); 		// Single product image
	update_option( 'shop_thumbnail_image_size', $thumbnail ); 	// Image gallery thumbs
}
add_action( 'after_switch_theme', 'smarty_woocommerce_image_dimensions', 1 );

/**
 * Load JavaScript and jQuery files for theme.
 *
 */
if ( version_compare( WOOCOMMERCE_VERSION, '2.3', '>=' ) ) {
    function gg_wc_scripts_loader() {
        wp_enqueue_script('woo-inputs', get_template_directory_uri() . '/js/woocommerce.js', array('jquery'), '', true); 
    }
    add_action('wp_enqueue_scripts', 'gg_wc_scripts_loader');
}


/* This snippet removes the action that inserts thumbnails to products in teh loop
 * and re-adds the function customized with our wrapper in it.
 * It applies to all archives with products.
 *
 * @original plugin: WooCommerce
 * @author of snippet: Brian Krogsard
 */
 
 if (get_theme_mod('store_product_hover', 1 ) == 1 ) {
	remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);
	add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10);

/*
 * WooCommerce Loop Product Thumbs
 */
 if ( ! function_exists( 'woocommerce_template_loop_product_thumbnail' ) ) {
	function woocommerce_template_loop_product_thumbnail() {
		echo woocommerce_get_product_thumbnail();
	} 
 }
 
/*
 * WooCommerce Product Thumbnail
 */
 if ( ! function_exists( 'woocommerce_get_product_thumbnail' ) ) {
	
	function woocommerce_get_product_thumbnail( $size = 'shop_catalog', $placeholder_width = 0, $placeholder_height = 0  ) {
		global $post, $product, $woocommerce;
		$output ='<figure>';

        if ( has_post_thumbnail() ) {
            $output .= get_the_post_thumbnail( $post->ID, $size );
         
	        $attachment_ids = $product->get_gallery_attachment_ids();
	        
			if ( $attachment_ids ) {
				$secondary_image_id = $attachment_ids['0'];
				$output .= '<figcaption class="img-rounded">'.(wp_get_attachment_image( $secondary_image_id, 'shop_catalog', '', $attr = array( 'class' => 'secondary-image wp-post-image' ) )).'</figcaption>';
			}
		}	

        elseif ( wc_placeholder_img_src() ) {
            $output .= wc_placeholder_img( $size );
        }

        $output .= '</figure>';

        return $output;

	}
 }
}

/*
 * Hide shop page title
 */
add_filter('woocommerce_show_page_title', 'remove_shop_page_title' );
function remove_shop_page_title() {
	return false;
}

/*
 * Add custom pagination
 */
remove_action('woocommerce_after_shop_loop', 'woocommerce_pagination', 10);
function woocommerce_pagination() {
		pagination(); 		
	}
add_action( 'woocommerce_after_shop_loop', 'woocommerce_pagination', 10);

/*
 * Allow shortcodes in product excerpts
 */
if (!function_exists('woocommerce_template_single_excerpt')) {
   function woocommerce_template_single_excerpt( $post ) {
   	   global $post;
       if ($post->post_excerpt) echo '<div itemprop="description">' . do_shortcode(wpautop(wptexturize($post->post_excerpt))) . '</div>';
   }
}

/*
 * Change number of products per row
 */
add_filter('loop_shop_columns', 'loop_columns');
if (!function_exists('loop_columns')) {
	function loop_columns() {
		return get_theme_mod('shop_product_columns','3');
	}
}

/*
 * Products per page
 */
add_filter('loop_shop_per_page',  'show_products_per_page');
function show_products_per_page() {
	$product_per_page = get_theme_mod('product_per_page','12');
    return $product_per_page;
}

/**
 * Add search fragment
 */
function woocommerceframework_add_search_fragment ( $settings ) {
	$settings['add_fragment'] = '?post_type=product';
	return $settings;
}

/**
 * Enable/Disable Sale Flash
 */
if ( get_theme_mod('store_sale_flash', 1) == 1 ) {
	remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
}
else {
	remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
	add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10);
}

/**
 * Enable/Disable Products price
 */
if ( get_theme_mod('store_products_price', 1) == 0 ) {
	remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10);
}
else {
	remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10);
	add_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_price', 10);
}

/**
 * Enable/Disable Add to cart
 */

if ( get_theme_mod('store_add_to_cart', 1) == 0 ) {
	remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart',10);
}
else {
	remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart',10);
	add_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart',10);
}

/**
 * Options for product page
 */

if ( get_theme_mod('product_sale_flash', 1) == 0 ) {	
	remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10);
}

if ( get_theme_mod('product_products_price', 1) == 0 ) {	
	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10);
}

if ( get_theme_mod('product_products_excerpt', 1) == 0 ) {	
	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20);
}

if ( get_theme_mod('product_add_to_cart', 1) == 0 ) {
	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30);
}

if ( get_theme_mod('product_products_meta', 1) == 0 ) {
	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40);
}

/**
 * Enable/Disable Review tab
 */
if ( get_theme_mod('product_reviews_tab', 1) == 0 ) {
add_filter( 'woocommerce_product_tabs', 'gg_woo_remove_reviews_tab', 98);
	function gg_woo_remove_reviews_tab($tabs) {
		unset($tabs['reviews']);
		return $tabs;
	}
}

/**
 * Enable/Disable Description tab
 */
if ( get_theme_mod('product_description_tab', 1) == 0 ) {
add_filter( 'woocommerce_product_tabs', 'gg_woo_remove_description_tab', 98);
	function gg_woo_remove_description_tab($tabs) {
		unset($tabs['description']);
		return $tabs;
	}
}

/**
 * Enable/Disable Attributes tab
 */
if ( get_theme_mod('product_attributes_tab', 1) == 0 ) {
add_filter( 'woocommerce_product_tabs', 'gg_woo_remove_attributes_tab', 98);
	function gg_woo_remove_attributes_tab($tabs) {
		unset($tabs['attributes']);
		return $tabs;
	}
}

/**
 * Enable/Disable Related products
 */
if ( get_theme_mod('product_related_products', 1) == 0 ) {
	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);
} else {
	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);
	add_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20);
}

//Display related products based on the number of columns the page has
add_filter( 'woocommerce_output_related_products_args', 'gg_related_products' );
function gg_related_products() {
	$page_layout = get_theme_mod('product_page_layout', 'no_sidebar');
	switch ($page_layout) {
	    case "with_right_sidebar":
	    case "with_left_sidebar":
	        $args = array('posts_per_page' => 3, 'columns' => 3,);
	        break;
	    case "no_sidebar":
	        $args = array('posts_per_page' => 4, 'columns' => 4,);
	        break;           
	}
    return $args;
}

/**
 * Enable/Disable Up Sells products
 */
if ( get_theme_mod('product_upsells_products', 1) == 0 ) {
	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
} else {
	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
	add_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_upsells', 15 );
}
if ( ! function_exists( 'woocommerce_output_upsells' ) ) {
	function woocommerce_output_upsells() {
	    woocommerce_upsell_display( 3,3 ); // Display 3 products in rows of 3
	}
}

/**
 * Enable/Disable Cross Sells products
 */
if ( get_theme_mod('product_crosssells_products' , 1) == 0) {
	remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );
	//remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display', 20 );
}

/**
 * Catalog mode functions (must be always the last function)
 **/

if (get_theme_mod('store_catalog_mode' , 0) == 1) {
	// Remove add to cart button from the product loop
	remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart',10);
	remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );

	// Remove add to cart button from the product details page
	remove_action( 'woocommerce_before_add_to_cart_form', 'woocommerce_template_single_product_add_to_cart', 10, 2);
	 
	//disabled actions (add to cart, checkout and pay)
	remove_action( 'init', 'woocommerce_add_to_cart_action', 10);
	remove_action( 'init', 'woocommerce_checkout_action', 10 );
	remove_action( 'init', 'woocommerce_pay_action', 10 );

}




// Handle cart in header fragment for ajax add to cart
add_filter('add_to_cart_fragments', 'woocommerceframework_header_add_to_cart_fragment');
function woocommerceframework_header_add_to_cart_fragment( $fragments ) {
	ob_start();
	?>

	<ul class="mini-cart">
		<li>
			<a href="<?php echo WC()->cart->get_cart_url(); ?>" title="<?php _e('View your shopping cart', 'okthemes'); ?>" class="cart-parent">
			<i class="icon_cart_alt"></i>
			<span> 
			<?php 
			echo sprintf(_n('<span class="total-items hidden-xs">%d product</span>', '<span class="total-items hidden-xs">%d products</span>', WC()->cart->cart_contents_count, 'okthemes'), WC()->cart->cart_contents_count);
			echo WC()->cart->get_cart_total();
			?>
			</span>
			</a>
			<?php
	
	        echo '<ul class="cart_list hidden-xs hidden-sm">';
	           if (sizeof(WC()->cart->cart_contents)>0) : foreach (WC()->cart->cart_contents as $cart_item_key => $cart_item) :
		           $_product = $cart_item['data'];
		           if ($_product->exists() && $cart_item['quantity']>0) :
		               echo '<li class="cart_list_product"><a href="'.get_permalink($cart_item['product_id']).'">';
		               
		               if (has_post_thumbnail($cart_item['product_id'])) echo get_the_post_thumbnail($cart_item['product_id'], 'shop_thumbnail'); 
		               
		               echo apply_filters('woocommerce_cart_widget_product_title', $_product->get_title(), $_product).'</a>';
		               
		               if($_product instanceof woocommerce_product_variation && is_array($cart_item['variation'])) :
		                   echo woocommerce_get_formatted_variation( $cart_item['variation'] );
		                 endif;
		               
		               echo '<span class="quantity">' .$cart_item['quantity'].' &times; '.woocommerce_price($_product->get_price()).'</span></li>';
		           endif;
		       endforeach;
	
	        	else: echo '<li class="empty">'.__('No products in the cart.','okthemes').'</li>'; endif;
	        	if (sizeof(WC()->cart->cart_contents)>0) :
	            echo '<li class="total"><strong>';
	
	            if (get_option('js_prices_include_tax')=='yes') :
	                _e('Total', 'okthemes');
	            else :
	                _e('Subtotal', 'okthemes');
	            endif;

	            echo ':</strong>'.WC()->cart->get_cart_total();'</li>';
	
	            echo '<li class="buttons"><a href="'.WC()->cart->get_cart_url().'" class="button">'.__('View Cart &rarr;','okthemes').'</a> <a href="'.WC()->cart->get_checkout_url().'" class="button checkout">'.__('Checkout &rarr;','okthemes').'</a></li>';
	        endif;
	        
	        echo '</ul>';
	
	    ?>
		</li>
	</ul>
	<?php
	$fragments['ul.mini-cart'] = ob_get_clean();
	return $fragments;
}

/**
 * Minicart function
 **/
if (!function_exists('header_mini_cart')) { 
function header_mini_cart() { ?>
<div class="header_mini_cart cart-contents woocommerce">
<ul class="mini-cart">
    <li>
        <a href="<?php echo WC()->cart->get_cart_url(); ?>" title="<?php _e('View your shopping cart', 'okthemes'); ?>" class="cart-parent">
        	<i class="icon_cart_alt"></i>
            <span> 
            <?php
			echo sprintf(_n('<span class="total-items hidden-xs">%d product</span>', '<span class="total-items hidden-xs">%d products</span>', WC()->cart->cart_contents_count, 'okthemes'), WC()->cart->cart_contents_count); 
            echo WC()->cart->get_cart_total();
            ?>
            </span>
        </a>
        <?php
            
            echo '<ul class="cart_list hidden-xs hidden-sm">';
               if (sizeof(WC()->cart->cart_contents)>0) : foreach (WC()->cart->cart_contents as $cart_item_key => $cart_item) :
                   $_product = $cart_item['data'];
                   if ($_product->exists() && $cart_item['quantity']>0) :
                       echo '<li class="cart_list_product"><a href="'.get_permalink($cart_item['product_id']).'">';
                       
                       if (has_post_thumbnail($cart_item['product_id'])) echo get_the_post_thumbnail($cart_item['product_id'], 'shop_thumbnail'); 
                       
                       echo apply_filters('woocommerce_cart_widget_product_title', $_product->get_title(), $_product).'</a>';
                       
                       if($_product instanceof woocommerce_product_variation && is_array($cart_item['variation'])) :
                           echo woocommerce_get_formatted_variation( $cart_item['variation'] );
                         endif;
                       
                       echo '<span class="quantity">' .$cart_item['quantity'].' &times; '.woocommerce_price($_product->get_price()).'</span></li>';
                   endif;
               endforeach;

                else: echo '<li class="empty">'.__('No products in the cart.','okthemes').'</li>'; endif;
                if (sizeof(WC()->cart->cart_contents)>0) :
                echo '<li class="total"><strong>';

                if (get_option('js_prices_include_tax')=='yes') :
                    _e('Total', 'okthemes');
                else :
                    _e('Subtotal', 'okthemes');
                endif;
                echo '</strong>'.WC()->cart->get_cart_total();'</li>';

                echo '<li class="buttons"><a href="'.WC()->cart->get_cart_url().'" class="button">'.__('View Cart &rarr;','okthemes').'</a> <a href="'.WC()->cart->get_checkout_url().'" class="button checkout">'.__('Checkout &rarr;','okthemes').'</a></li>';
            endif;
            echo '</ul>';
        ?>
    </li>
</ul>
</div>

<?php } 

}

/**
 * Handle wc_fragments for wpml currency
 **/
if ( class_exists('woocommerce_wpml') ) {
	wc_enqueue_js( "
		jQuery('.wcml_currency_switcher').on('change', function(){                   
	        sessionStorage.removeItem('wc_fragments');
	    });
	    jQuery('.wcml_currency_switcher li').on('click', function(){
	        sessionStorage.removeItem('wc_fragments');
	    });
	" );
}