<?php
/**
 * Adds gg_Contact_Widget widget.
 */
class gg_Contact_Widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'gg_contact_widget', // Base ID
			__('Contact Widget', 'okthemes'), // Name
			array( 'description' => __( 'Contact us Widget', 'okthemes' ), 'classname' => 'contact', ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 */
	public function widget( $args, $instance ) {
		$title = apply_filters( 'widget_title', $instance['title'] );
		$other_details = ! empty( $instance['other_details'] ) ? $instance['other_details'] : '';
		$address = ! empty( $instance['address'] ) ? $instance['address'] : '';
		$phone = ! empty( $instance['phone'] ) ? $instance['phone'] : '';
		$fax = ! empty( $instance['fax'] ) ? $instance['fax'] : '';
		$email = ! empty( $instance['email'] ) ? $instance['email'] : '';

		echo $args['before_widget'];

		if ( ! empty( $title ) )
			echo $args['before_title'] . $title . $args['after_title'];

		echo '<ul>';

		if ( $other_details )
			echo '<li class="other-details">'.$other_details.' </li>';

		if ( $address )
			echo '<li class="contact-widget-address">'.$address.' </li>';

		if ( $phone )
			echo '<li class="contact-widget-phone">'.$phone.' </li>';

		if ( $fax )
			echo '<li class="contact-widget-fax">'.$fax.' </li>';

		if ( $email )
			echo '<li class="contact-widget-email"><a href="mailto:'.$email.'">'.$email.'</a></li>';

		echo '</ul>';

		echo $args['after_widget'];
	}
	

	/**
	 * Back-end widget form.
	 */
	public function form( $instance ) {
		
		$title = isset( $instance['title'] ) ? $instance['title'] : __( 'Contact us', 'okthemes' );
		$other_details = esc_textarea($instance['other_details']);
		$address = esc_textarea($instance['address']);
		$phone = isset( $instance['phone'] ) ? $instance['phone'] : '';
		$fax = isset( $instance['fax'] ) ? $instance['fax'] : '';
		$email = isset( $instance['email'] ) ? $instance['email'] : '';

		?>
		
		<!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title:', 'okthemes'); ?></label>
			<input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" class="widefat" />
		</p>
		<!-- Other details: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'other_details' ); ?>"><?php _e('Other details:', 'okthemes'); ?></label>
			<textarea class="widefat" id="<?php echo $this->get_field_id('other_details'); ?>" name="<?php echo $this->get_field_name('other_details'); ?>"><?php echo $other_details; ?></textarea>
		</p>
		<!-- Your Address: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'address' ); ?>"><?php _e('Your Address:', 'okthemes'); ?></label>
			<textarea class="widefat" id="<?php echo $this->get_field_id('address'); ?>" name="<?php echo $this->get_field_name('address'); ?>"><?php echo $address; ?></textarea>
		</p>
		<!-- Your Phone: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'phone' ); ?>"><?php _e('Your Phone:', 'okthemes'); ?></label>
			<input id="<?php echo $this->get_field_id( 'phone' ); ?>" name="<?php echo $this->get_field_name( 'phone' ); ?>" value="<?php echo $instance['phone']; ?>" class="widefat" />
		</p>
		<!-- Your Fax: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'fax' ); ?>"><?php _e('Your Fax:', 'okthemes'); ?></label>
			<input id="<?php echo $this->get_field_id( 'fax' ); ?>" name="<?php echo $this->get_field_name( 'fax' ); ?>" value="<?php echo $instance['fax']; ?>" class="widefat" />
		</p>
		<!-- Your E-mail: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'email' ); ?>"><?php _e('Your Email:', 'okthemes'); ?></label>
			<input id="<?php echo $this->get_field_id( 'email' ); ?>" name="<?php echo $this->get_field_name( 'email' ); ?>" value="<?php echo $instance['email']; ?>" class="widefat" />
		</p>
		<?php 
	}


	/**
	 * Sanitize widget form values as they are saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = array();

		$instance['title'] = ( ! empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['other_details'] =  $new_instance['other_details'];
		$instance['address'] =  $new_instance['address'];
		$instance['phone'] = ( ! empty( $new_instance['phone'] ) ) ? strip_tags( $new_instance['phone'] ) : '';
		$instance['fax'] = ( ! empty( $new_instance['fax'] ) ) ? strip_tags( $new_instance['fax'] ) : '';
		$instance['email'] = ( ! empty( $new_instance['email'] ) ) ? strip_tags( $new_instance['email'] ) : '';
		
		return $instance;
	}


} // class gg_Contact_Widget

// register gg_Contact_Widget 
function register_gg_contact_widget() {
    register_widget( 'gg_Contact_Widget' );
}
add_action( 'widgets_init', 'register_gg_contact_widget' );