<?php
/**
 * Post type: Portfolio
 * Displays recent posts including the post date.
 */
class portfolio_post_type_widget extends WP_Widget {

	function __construct() {
		parent::__construct(
			'portfolio_post_type_widget', // Base ID
			__('Post type: Portfolio', 'okthemes'), // Name
			array( 'description' => __( 'Portfolio post type posts', 'okthemes' ), 'classname' => 'portfolio_post_type_widget', ) // Args
		);

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('portfolio_post_type_widget', 'widget');

		if ( !is_array($cache) ) $cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start(); 
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('portfolio', 'okthemes') : $instance['title']);
		if ( !$number = (int) $instance['number'] ) $number = 10;
		else if ( $number < 1 ) $number = 1;
		else if ( $number > 15 ) $number = 15;
		
		$carousel = !empty( $instance['carousel'] ) ? '1' : '0';
		
		$category = (!empty($instance['category']) ? $instance['category'] : 'All posts');
		
		$rand_ID = rand();

		//verify category selection
		if( $category == 'All posts' ) {
			$r = new WP_Query( array( 'post_type' => 'portfolio_cpt', 'posts_per_page' => $number) );
		} else {
			$r = new WP_Query( array( 'post_type' => 'portfolio_cpt', 'portfolio_category' => $category, 'posts_per_page' => $number) );	
		}
		
		if ($r->have_posts()) : 
			//Load magnific 
            wp_enqueue_script('magnific');
            wp_enqueue_style('magnific');

            $is_carousel = '';
			$carousel_data = '';
			$convert_ul = 'ul';
			$convert_li = 'li';

			if ($carousel == '1') {
				//Load carousel
				wp_enqueue_script('owlcarousel');

				$is_carousel = 'owl-carousel';
				$convert_ul = 'div';
				$convert_li = 'div';
				$carousel_data = 'data-slides-per-view = "1" data-single-item = "true" data-transition-slide = "fade" data-navigation-owl = "false" data-pagination-owl = "true"';
			}

		?>
        
		<?php echo $before_widget; ?>
        
		<?php 
		if ( $title ) echo $before_title . $title . $after_title;
        echo '<'.$convert_ul.' '.$carousel_data.' class="image-grid '.$is_carousel.'">';
			while ($r->have_posts()) : $r->the_post();
				echo '<'.$convert_li.'>';
		            get_template_part( 'parts/part','portfolio' );
		        echo '</'.$convert_li.'>';
			endwhile;
		echo '</'.$convert_ul.'>';
		?>
        
		<?php echo $after_widget; ?>
        
		<?php wp_reset_query();  // Restore global post data stomped by the_post().
		endif;
		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_add('portfolio_post_type_widget', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$new_instance = wp_parse_args( (array) $new_instance, array( 'title' => '', 'carousel' => 0, 'number' => '', 'category' => '') );
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$instance['carousel'] = $new_instance['carousel'] ? 1 : 0;
		$instance['category'] = $new_instance['category'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['portfolio_post_type_widget']) )
			delete_option('portfolio_post_type_widget');

		return $instance;
	}

	function flush_widget_cache() {wp_cache_delete('portfolio_post_type_widget', 'widget');}

	function form( $instance ) {
		//Defaults
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'carousel' => 0, 'number' => 5) );
		//Title
		$title = strip_tags($instance['title']);
		//No of posts
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 5;
		//Carousel	
		$carousel = $instance['carousel'] ? 'checked="checked"' : '';
		//Category
		$category = esc_attr($instance['category']);

		$categories = get_terms("portfolio_category");
		$cat_options = array();
		$cat_options[] = '<option value="All posts">All posts</option>';
		foreach ($categories as $cat) {
			$selected = $category === $cat->slug ? ' selected="selected"' : '';
			$cat_options[] = '<option value="' . $cat->slug .'"' . $selected . '>' . $cat->name . '</option>';
		}

			
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'okthemes'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of posts to show:', 'okthemes'); ?></label>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /><br />
		<small><?php _e('(at most 15)', 'okthemes'); ?></small></p>
        
        <p>
            <label for="<?php echo $this->get_field_id('category'); ?>">
                <?php _e('Select category' , 'okthemes'); ?>
            </label>
            <select id="<?php echo $this->get_field_id('category'); ?>" class="widefat" name="<?php echo $this->get_field_name('category'); ?>">
                <?php echo implode('', $cat_options); ?>
            </select>
            <small><?php _e('(Select the category from where the posts must be pulled.)', 'okthemes'); ?></small>
        </p>
        
        <p><label for="<?php echo $this->get_field_id('carousel'); ?>"><?php _e('Carousel mode' , 'okthemes'); ?></label>
        <input class="checkbox" type="checkbox" <?php if ($instance['carousel']) echo 'checked="checked" '; ?>id="<?php echo $this->get_field_id('carousel'); ?>" name="<?php echo $this->get_field_name('carousel'); ?>"><br />
        <small><?php _e('(Enable/Disable carousel mode)', 'okthemes'); ?></small></p>
		
<?php
	}
}

function portfolio_post_type_widget_init() {register_widget('portfolio_post_type_widget');}
add_action('widgets_init', 'portfolio_post_type_widget_init');
?>